@@ -356,27 +356,27 @@ void GUI::import()
 void GUI::setupActions()
 {
     KActionCollection *ac = actionCollection();
-    QAction *new_action = KStandardAction::openNew(this, &GUI::createTorrent, ac);
+    QAction *new_action = KStandardActions::openNew(this, &GUI::createTorrent, ac);
     new_action->setToolTip(i18n("Create a new torrent"));
-    QAction *open_action = KStandardAction::open(this, &GUI::openTorrent, ac);
+    QAction *open_action = KStandardActions::open(this, &GUI::openTorrent, ac);
     open_action->setToolTip(i18n("Open a torrent"));
-    paste_action = KStandardAction::paste(this, &GUI::paste, ac);
+    paste_action = KStandardActions::paste(this, &GUI::paste, ac);
 
     open_silently_action = new QAction(open_action->icon(), i18n("Open Silently"), this);
     open_silently_action->setToolTip(i18n("Open a torrent without asking any questions"));
     connect(open_silently_action, &QAction::triggered, this, &GUI::openTorrentSilently);
     ac->addAction(QStringLiteral("file_open_silently"), open_silently_action);
 
-    KStandardAction::quit(this, &GUI::quit, ac);
+    KStandardActions::quit(this, &GUI::quit, ac);
 
     show_status_bar_action = KStandardAction::showStatusbar(statusBar(), &GUI::setVisible, ac);
     show_status_bar_action->setIcon(QIcon::fromTheme(QStringLiteral("kt-show-statusbar")));
 
     show_menu_bar_action = KStandardAction::showMenubar(menuBar(), &GUI::setVisible, ac);
-    KStandardAction::preferences(this, &GUI::showPrefDialog, ac);
-    KStandardAction::keyBindings(this, &GUI::configureKeys, ac);
-    KStandardAction::configureToolbars(this, &GUI::configureToolbars, ac);
-    KStandardAction::configureNotifications(this, &GUI::configureNotifications, ac);
+    KStandardActions::preferences(this, &GUI::showPrefDialog, ac);
+    KStandardActions::keyBindings(this, &GUI::configureKeys, ac);
+    KStandardActions::configureToolbars(this, &GUI::configureToolbars, ac);
+    KStandardActions::configureNotifications(this, &GUI::configureNotifications, ac);
 
     paste_url_action = new QAction(QIcon::fromTheme(QStringLiteral("document-open-remote")), i18n("Open URL"), this);
     paste_url_action->setToolTip(i18n("Open a URL which points to a torrent, magnet links are supported"));
